pub struct Row { /* private fields */ }
A row.

Implementations

Read the value in a column.

In case of integer indices, the first column has index 0.

Panics

Panics if the column could not be read.

Try to read the value in a column.

In case of integer indices, the first column has index 0.