pub trait BindableWithIndex {
    fn bind<T: ParameterIndex>(self, _: &mut Statement, _: T) -> Result<()>;
}
A type suitable for binding to a prepared statement given a parameter index.

Required Methods

Bind to a parameter.

In case of integer indices, the first parameter has index 1.

Implementations on Foreign Types

Implementors