pub trait ReadableWithIndex: Sized {
    fn read<T: ColumnIndex>(_: &Statement, _: T) -> Result<Self>;
}
A type suitable for reading from a prepared statement given a column index.

Required Methods

Read from a column.

In case of integer indices, the first column has index 0.

Implementations on Foreign Types

Implementors